package com.qiaoba.module.system.mapper;

import com.qiaoba.api.system.entity.SysMenu;
import com.qiaoba.api.system.entity.vo.SysMenuVo;
import com.qiaoba.common.database.mapper.BaseMapperPlus;

import java.util.List;
import java.util.Set;

/**
 * 菜单管理 数据层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/5 11:36
 */
public interface SysMenuMapper extends BaseMapperPlus<SysMenuMapper, SysMenu, SysMenuVo> {

    /**
     * 校验菜单名称是否唯一
     *
     * @param sysMenu 菜单
     * @return count
     */
    String checkMenuNameUnique(SysMenu sysMenu);

    /**
     * 校验是否有子菜单
     *
     * @param menuId menuId
     * @return != null -> 是
     */
    String existChild(String menuId);

    /**
     * 校验菜单是否被绑定
     *
     * @param menuId menuId
     * @return 绑定的角色名称
     */
    String existUsed(String menuId);

    /**
     * 根据角色ID查询菜单树信息
     *
     * @param roleId 角色ID
     * @return 选中菜单ID列表
     */
    List<String> selectMenuIdsByRoleId(String roleId);

    /**
     * 通过 userId 查询目录和菜单
     *
     * @param userId userId
     * @return list
     */
    List<SysMenuVo> selectByUserId(String userId);

    /**
     * 查询用户拥有的权限列表
     *
     * @param userId userId
     * @return 权限列表
     */
    Set<String> selectPermsByUserId(String userId);
}
