package com.qiaoba.module.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.qiaoba.api.system.entity.SysUserRole;
import com.qiaoba.auth.entity.dto.RoleDto;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 用户角色关联 数据层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/9 9:50
 */
public interface SysUserRoleMapper extends BaseMapper<SysUserRole> {

    /**
     * 通过userId查询所绑定的角色ID列表
     *
     * @param userId userId
     * @param status 状态
     * @return roleIds
     */
    List<String> selectRoleIdsByUserId(@Param("userId") String userId, @Param("status") String status);

    /**
     * 批量取消角色所绑定的用户
     *
     * @param roleId  roleId
     * @param userIds userIds
     */
    void deleteByRoleIdAndUserIds(@Param("roleId") String roleId, @Param("list") List<String> userIds);

    /**
     * 通过userIds删除
     *
     * @param userIds userIds
     */
    void deleteByUserIds(@Param("list") List<String> userIds);

    /**
     * 通过userId查询所绑定的角色(id + name)列表
     *
     * @param userId userId
     * @param status 状态
     * @return roles
     */
    List<RoleDto> selectRoleDtoByUserId(@Param("userId") String userId, @Param("status") String status);
}
