package com.qiaoba.module.system.service;

import cn.hutool.core.lang.tree.Tree;
import com.qiaoba.api.system.entity.vo.RouterVo;
import com.qiaoba.api.system.entity.vo.SysMenuVo;
import com.qiaoba.api.system.service.SysMenuApiService;

import java.util.List;
import java.util.Set;

/**
 * 菜单管理 服务层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/5/5 11:30
 */
public interface SysMenuService extends SysMenuApiService {


    /**
     * 构建前端所需要下拉树结构
     *
     * @param menus 菜单列表
     * @return 下拉树结构列表
     */
    List<Tree<String>> buildMenuTree(List<SysMenuVo> menus);

    /**
     * 根据角色ID查询菜单树信息
     *
     * @param roleId 角色ID
     * @return 选中菜单ID列表
     */
    List<String> selectMenuIdsByRoleId(String roleId);

    /**
     * 通过 userId 查询目录和菜单
     *
     * @param userId userId
     * @return list
     */
    List<SysMenuVo> selectByUserId(String userId);

    /**
     * 查询用户拥有的权限列表
     *
     * @param userId userId
     * @return 权限列表
     */
    Set<String> selectPermsByUserId(String userId);

    /**
     * 菜单转路由
     *
     * @param menus 菜单列表
     * @return 路由列表
     */
    List<RouterVo> menusToRouters(List<SysMenuVo> menus);
}
